@@ -1,7 +1,29 @@
+// TITLE
+//
+//    R-TREES: A DYNAMIC INDEX STRUCTURE FOR SPATIAL SEARCHING
+//
+// DESCRIPTION
+//
+//    A C++ templated version of the RTree algorithm.
+//    For more information please read the comments in RTree.h
+//
+// AUTHORS
+//
+//    * 1983 Original algorithm and test code by Antonin Guttman
+//      and Michael Stonebraker, UC Berkely
+//    * 1994 ANSI C ported from original test code by Melinda Green
+//      (melinda@superliminal.com)
+//    * 1995 Sphere volume fix for degeneracy problem submitted by Paul Brook
+//    * 2004 Templated C++ port by Greg Douglas
+//    * 2018 Iterator fix and Qt macros by Martin Tuma
+//
+// LICENSE:
+//
+//    Entirely free for all uses. Enjoy!
+
 #ifndef RTREE_H
 #define RTREE_H
 
-#include <cstdio>
 #include <cmath>
 #include <cstdlib>
 #include <QtGlobal>
@@ -58,6 +80,7 @@ public:
 public:
 
 	RTree();
+	RTree(const RTree &) = delete;
 	virtual ~RTree();
 
 	/// Insert entry
@@ -92,7 +115,7 @@ public:
 
 	/// Count the data elements in this container.  This is slow as no internal
 	/// counter is maintained.
-	int Count();
+	int Count() const;
 
 
 	/// Iterator is not remove safe.
@@ -220,7 +243,7 @@ public:
 	};
 
 	// Get 'first' for iteration
-	void GetFirst(Iterator& a_it)
+	void GetFirst(Iterator& a_it) const
 	{
 		a_it.Init();
 		Node* first = m_root;
@@ -239,13 +262,13 @@ public:
 	}
 
 	// Get Next for iteration
-	void GetNext(Iterator& a_it) { ++a_it; }
+	void GetNext(Iterator& a_it) const { ++a_it; }
 
 	// Is iterator NULL, or at end?
-	bool IsNull(Iterator& a_it) { return a_it.IsNull(); }
+	bool IsNull(Iterator& a_it) const { return a_it.IsNull(); }
 
 	// Get object at iterator position
-	DATATYPE& GetAt(Iterator& a_it) { return *a_it; }
+	DATATYPE& GetAt(Iterator& a_it) const { return *a_it; }
 
 protected:
 	// Minimal bounding rectangle (n-dimensional)
@@ -340,7 +363,7 @@ protected:
 	  void* a_context) const;
 	void RemoveAllRec(Node* a_node);
 	void Reset();
-	void CountRec(Node* a_node, int& a_count);
+	void CountRec(Node* a_node, int& a_count) const;
 
 	/// Root of tree
 	Node* m_root;
@@ -387,10 +410,10 @@ RTREE_TEMPLATE
 void RTREE_QUAL::Insert(const ELEMTYPE a_min[NUMDIMS],
   const ELEMTYPE a_max[NUMDIMS], const DATATYPE& a_dataId)
 {
-	#ifdef _DEBUG
+	#ifndef QT_NO_DEBUG
 	for (int index=0; index<NUMDIMS; ++index)
 		Q_ASSERT(a_min[index] <= a_max[index]);
-	#endif //_DEBUG
+	#endif // QT_NO_DEBUG
 
 	Rect rect;
 
@@ -407,10 +430,10 @@ RTREE_TEMPLATE
 void RTREE_QUAL::Remove(const ELEMTYPE a_min[NUMDIMS],
   const ELEMTYPE a_max[NUMDIMS], const DATATYPE& a_dataId)
 {
-	#ifdef _DEBUG
+	#ifndef QT_NO_DEBUG
 	for (int index=0; index<NUMDIMS; ++index)
 		Q_ASSERT(a_min[index] <= a_max[index]);
-	#endif //_DEBUG
+	#endif // QT_NO_DEBUG
 
 	Rect rect;
 
@@ -427,10 +450,10 @@ RTREE_TEMPLATE
 int RTREE_QUAL::Search(const ELEMTYPE a_min[NUMDIMS], const ELEMTYPE a_max[NUMDIMS],
   bool a_resultCallback(DATATYPE a_data, void* a_context), void* a_context) const
 {
-	#ifdef _DEBUG
+	#ifndef QT_NO_DEBUG
 	for (int index=0; index<NUMDIMS; ++index)
 		Q_ASSERT(a_min[index] <= a_max[index]);
-	#endif //_DEBUG
+	#endif // QT_NO_DEBUG
 
 	Rect rect;
 
@@ -450,7 +473,7 @@ int RTREE_QUAL::Search(const ELEMTYPE a_min[NUMDIMS], const ELEMTYPE a_max[NUMDI
 
 
 RTREE_TEMPLATE
-int RTREE_QUAL::Count()
+int RTREE_QUAL::Count() const
 {
 	int count = 0;
 	CountRec(m_root, count);
@@ -460,7 +483,7 @@ int RTREE_QUAL::Count()
 
 
 RTREE_TEMPLATE
-void RTREE_QUAL::CountRec(Node* a_node, int& a_count)
+void RTREE_QUAL::CountRec(Node* a_node, int& a_count) const
 {
 	if (a_node->IsInternalNode()) {  // not a leaf node
 		for (int index = 0; index < a_node->m_count; ++index)
@@ -636,10 +659,10 @@ bool RTREE_QUAL::InsertRect(Rect* a_rect, const DATATYPE& a_id, Node** a_root,
 {
 	Q_ASSERT(a_rect && a_root);
 	Q_ASSERT(a_level >= 0 && a_level <= (*a_root)->m_level);
-	#ifdef _DEBUG
+	#ifndef QT_NO_DEBUG
 	for (int index=0; index < NUMDIMS; ++index)
 		Q_ASSERT(a_rect->m_min[index] <= a_rect->m_max[index]);
-	#endif //_DEBUG  
+	#endif // QT_NO_DEBUG
 
 	Node* newRoot;
 	Node* newNode;
