@@ -131,8 +131,8 @@ DEM::Entry *DEM::loadTile(const Tile &tile)
 	} else {
 		QFile file(path);
 		if (!file.open(QIODevice::ReadOnly)) {
-			qWarning("%s: %s", qPrintable(file.fileName()),
-			  qPrintable(file.errorString()));
+			qWarning("%s: %s", qUtf8Printable(file.fileName()),
+			  qUtf8Printable(file.errorString()));
 			return new Entry();
 		} else
 			return new Entry(file.readAll());
@@ -182,6 +182,25 @@ MatrixD DEM::elevation(const MatrixC &m)
 	return ret;
 }
 
+bool DEM::elevation(const RectC &rect)
+{
+	QDir dir(_dir);
+	int left = floor(rect.left());
+	int top = floor(rect.top());
+	int right = floor(rect.right());
+	int bottom = floor(rect.bottom());
+
+	for (int i = bottom; i <= top; i++) {
+		for (int j = left; j <= right; j++) {
+			QString path(dir.absoluteFilePath(Tile(j, i).fileName()));
+			if (QFileInfo::exists(path) || QFileInfo::exists(path + ".zip"))
+				return true;
+		}
+	}
+
+	return false;
+}
+
 QList<Area> DEM::tiles()
 {
 	static const QRegularExpression re(
