@@ -155,14 +155,19 @@ JNXMap::~JNXMap()
 }
 
 void JNXMap::load(const Projection &in, const Projection &out,
-  qreal deviceRatio, bool hidpi)
+  qreal deviceRatio, bool hidpi, int style, int layer)
 {
 	Q_UNUSED(out);
+	Q_UNUSED(layer);
+	Q_UNUSED(style);
 
 	_projection = in;
 	_mapRatio = hidpi ? deviceRatio : 1.0;
 
-	if (_file.open(QIODevice::ReadOnly))
+	if (!_file.open(QIODevice::ReadOnly))
+		qWarning("%s: %s", qUtf8Printable(_file.fileName()),
+		  qUtf8Printable(_file.errorString()));
+	else
 		readTiles();
 }
 
