@@ -14,6 +14,7 @@
 #define MAX_TILE_SIZE 4096
 
 using namespace MVT;
+using namespace OSM;
 
 static RectC str2bounds(const QString &str)
 {
@@ -40,7 +41,7 @@ const Style *MBTilesMap::defaultStyle() const
 
 	qWarning("%s: no matching MVT style found", qUtf8Printable(path()));
 
-	return 0;
+	return Style::styles().isEmpty() ? 0 : Style::styles().first();
 }
 
 bool MBTilesMap::getMinZoom(int &zoom)
@@ -56,7 +57,7 @@ bool MBTilesMap::getMinZoom(int &zoom)
 		}
 	} else {
 		qWarning("%s: missing minzoom metadata", qUtf8Printable(path()));
-		zoom = OSM::ZOOMS.min();
+		zoom = ZOOMS.min();
 	}
 
 	return true;
@@ -75,7 +76,7 @@ bool MBTilesMap::getMaxZoom(int &zoom)
 		}
 	} else {
 		qWarning("%s: missing maxzoom metadata", qUtf8Printable(path()));
-		zoom = OSM::ZOOMS.max();
+		zoom = ZOOMS.max();
 	}
 
 	return true;
@@ -130,11 +131,11 @@ bool MBTilesMap::getBounds()
 		int minY = qMin((1<<z) - 1, qMax(0, query.value(1).toInt()));
 		int maxX = qMin((1<<z) - 1, qMax(0, query.value(2).toInt())) + 1;
 		int maxY = qMin((1<<z) - 1, qMax(0, query.value(3).toInt())) + 1;
-		Coordinates tl(OSM::tile2ll(QPoint(minX, maxY), z));
-		Coordinates br(OSM::tile2ll(QPoint(maxX, minY), z));
+		Coordinates tl(tile2ll(QPoint(minX, maxY), z));
+		Coordinates br(tile2ll(QPoint(maxX, minY), z));
 		// Workaround of broken zoom levels 0 and 1 due to numerical instability
-		tl.rlat() = qMin(tl.lat(), OSM::BOUNDS.top());
-		br.rlat() = qMax(br.lat(), OSM::BOUNDS.bottom());
+		tl.rlat() = qMin(tl.lat(), BOUNDS.top());
+		br.rlat() = qMax(br.lat(), BOUNDS.bottom());
 		_bounds = RectC(tl, br);
 	}
 
@@ -269,7 +270,7 @@ void MBTilesMap::load(const Projection &in, const Projection &out,
 		_style = (style >= 0 && style < Style::styles().size())
 		  ? Style::styles().at(style) : defaultStyle();
 
-		for (int i = _zooms.last().base + 1; i <= OSM::ZOOMS.max(); i++) {
+		for (int i = _zooms.last().base + 1; i <= ZOOMS.max(); i++) {
 			Zoom z(i, _zooms.last().base);
 			if (_tileSize * _tileRatio * (1U<<(z.z - z.base)) > MAX_TILE_SIZE)
 				break;
@@ -279,6 +280,9 @@ void MBTilesMap::load(const Projection &in, const Projection &out,
 		QPixmapCache::clear();
 	}
 
+	_coordinatesRatio = _mapRatio > 1.0 ? _mapRatio / _tileRatio : 1.0;
+	_factor = zoom2scale(_zooms.at(_zoom).z, _tileSize) * _coordinatesRatio;
+
 	_db.open();
 }
 
@@ -293,14 +297,19 @@ QRectF MBTilesMap::bounds()
 	return QRectF(ll2xy(_bounds.topLeft()), ll2xy(_bounds.bottomRight()));
 }
 
+qreal MBTilesMap::resolution(const QRectF &rect)
+{
+	return OSM::resolution(rect.center(), _zooms.at(_zoom).z, tileSize());
+}
+
 int MBTilesMap::zoomFit(const QSize &size, const RectC &rect)
 {
 	if (!rect.isValid())
 		_zoom = _zooms.size() - 1;
 	else {
-		QRectF tbr(OSM::ll2m(rect.topLeft()), OSM::ll2m(rect.bottomRight()));
+		QRectF tbr(ll2m(rect.topLeft()), ll2m(rect.bottomRight()));
 		QPointF sc(tbr.width() / size.width(), tbr.height() / size.height());
-		int zoom = OSM::scale2zoom(qMax(sc.x(), -sc.y()) / coordinatesRatio(),
+		int zoom = scale2zoom(qMax(sc.x(), -sc.y()) / _coordinatesRatio,
 		  _tileSize);
 
 		_zoom = 0;
@@ -311,12 +320,15 @@ int MBTilesMap::zoomFit(const QSize &size, const RectC &rect)
 		}
 	}
 
+	_factor = zoom2scale(_zooms.at(_zoom).z, _tileSize) * _coordinatesRatio;
+
 	return _zoom;
 }
 
-qreal MBTilesMap::resolution(const QRectF &rect)
+void MBTilesMap::setZoom(int zoom)
 {
-	return OSM::resolution(rect.center(), _zooms.at(_zoom).z, tileSize());
+	_zoom = zoom;
+	_factor = zoom2scale(_zooms.at(_zoom).z, _tileSize) * _coordinatesRatio;
 }
 
 int MBTilesMap::zoomIn()
@@ -324,6 +336,8 @@ int MBTilesMap::zoomIn()
 	cancelJobs(false);
 
 	_zoom = qMin(_zoom + 1, _zooms.size() - 1);
+	_factor = zoom2scale(_zooms.at(_zoom).z, _tileSize) * _coordinatesRatio;
+
 	return _zoom;
 }
 
@@ -332,22 +346,14 @@ int MBTilesMap::zoomOut()
 	cancelJobs(false);
 
 	_zoom = qMax(_zoom - 1, 0);
+	_factor = zoom2scale(_zooms.at(_zoom).z, _tileSize) * _coordinatesRatio;
+
 	return _zoom;
 }
 
-qreal MBTilesMap::coordinatesRatio() const
-{
-	return _mapRatio > 1.0 ? _mapRatio / _tileRatio : 1.0;
-}
-
-qreal MBTilesMap::imageRatio() const
-{
-	return _mapRatio > 1.0 ? _mapRatio : _tileRatio;
-}
-
 qreal MBTilesMap::tileSize() const
 {
-	return (_tileSize / coordinatesRatio());
+	return (_tileSize / _coordinatesRatio);
 }
 
 QByteArray MBTilesMap::tileData(int zoom, const QPoint &tile) const
@@ -432,11 +438,9 @@ void MBTilesMap::draw(QPainter *painter, const QRectF &rect, Flags flags)
 {
 	const Zoom &zoom = _zooms.at(_zoom);
 	unsigned overzoom = zoom.z - zoom.base;
-	qreal scale = OSM::zoom2scale(zoom.base, _tileSize << overzoom);
-	QPoint tile = OSM::mercator2tile(QPointF(rect.topLeft().x() * scale,
-	  -rect.topLeft().y() * scale) * coordinatesRatio(), zoom.base);
-	QPointF tlm(OSM::tile2mercator(tile, zoom.base));
-	QPointF tl(QPointF(tlm.x() / scale, tlm.y() / scale) / coordinatesRatio());
+	QPoint tile = mercator2tile(QPointF(rect.topLeft().x(),
+	  -rect.topLeft().y()) * _factor, zoom.base);
+	QPointF tl(tile2mercator(tile, zoom.base) / _factor);
 	QSizeF s(rect.right() - tl.x(), rect.bottom() - tl.y());
 	unsigned f = 1U<<overzoom;
 	int width = ceil(s.width() / (tileSize() * f));
@@ -456,8 +460,9 @@ void MBTilesMap::draw(QPainter *painter, const QRectF &rect, Flags flags)
 				QPointF tp(tilePos(tl, t, tile, overzoom));
 				drawTile(painter, pm, tp);
 			} else
-				tiles.append(RasterTile(tileData(zoom.base, t), _mvt, true,
-				  _style, zoom.z, t, _tileSize, _tileRatio, overzoom));
+				tiles.append(RasterTile(Source(tileData(zoom.base, t), true,
+				  _mvt), _style, zoom.z, t, _tileSize, _tileRatio, overzoom,
+				  flags & Map::HillShading));
 		}
 	}
 
@@ -484,22 +489,24 @@ void MBTilesMap::draw(QPainter *painter, const QRectF &rect, Flags flags)
 
 void MBTilesMap::drawTile(QPainter *painter, QPixmap &pixmap, QPointF &tp)
 {
-	pixmap.setDevicePixelRatio(imageRatio());
+	pixmap.setDevicePixelRatio(_mapRatio > 1.0 ? _mapRatio : _tileRatio);
 	painter->drawPixmap(tp, pixmap);
 }
 
 QPointF MBTilesMap::ll2xy(const Coordinates &c)
 {
-	qreal scale = OSM::zoom2scale(_zooms.at(_zoom).z, _tileSize);
-	QPointF m = OSM::ll2m(c);
-	return QPointF(m.x() / scale, m.y() / -scale) / coordinatesRatio();
+	QPointF m = ll2m(c);
+	return QPointF(m.x(), -m.y()) / _factor;
 }
 
 Coordinates MBTilesMap::xy2ll(const QPointF &p)
 {
-	qreal scale = OSM::zoom2scale(_zooms.at(_zoom).z, _tileSize);
-	return OSM::m2ll(QPointF(p.x() * scale, -p.y() * scale)
-	  * coordinatesRatio());
+	return m2ll(QPointF(p.x(), -p.y()) * _factor);
+}
+
+bool MBTilesMap::hillShading() const
+{
+	return _style && _style->hasHillShading();
 }
 
 QStringList MBTilesMap::styles(int &defaultStyle) const
@@ -512,8 +519,6 @@ QStringList MBTilesMap::styles(int &defaultStyle) const
 			list.append(Style::styles().at(i)->name());
 
 		defaultStyle = Style::styles().indexOf(_style);
-		if (defaultStyle < 0)
-			defaultStyle = 0;
 	} else
 		defaultStyle = -1;
 
